@@ -1,7 +1,7 @@
 package Complete::Module;
 
-our $DATE = '2015-03-03'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2015-03-13'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,8 +24,10 @@ if ($ENV{COMPLETE_MODULE_OPT_SHORTCUT_PREFIXES}) {
     $OPT_SHORTCUT_PREFIXES = {
         dzb => 'Dist/Zilla/PluginBundle/',
         dzp => 'Dist/Zilla/Plugin/',
+        dzr => 'Dist/Zilla/Role/',
         pwb => 'Pod/Weaver/PluginBundle/',
         pwp => 'Pod/Weaver/Plugin/',
+        pwr => 'Pod/Weaver/Role/',
         pws => 'Pod/Weaver/Section/',
     };
 }
@@ -223,7 +225,7 @@ Complete::Module - Complete with installed Perl module names
 
 =head1 VERSION
 
-This document describes version 0.16 of Complete::Module (from Perl distribution Complete-Module), released on 2015-03-03.
+This document describes version 0.17 of Complete::Module (from Perl distribution Complete-Module), released on 2015-03-13.
 
 =head1 SYNOPSIS
 
@@ -318,8 +320,10 @@ Shortcut prefixes. The default is:
  {
    dzb => "Dist/Zilla/PluginBundle/",
    dzp => "Dist/Zilla/Plugin/",
+   dzr => "Dist/Zilla/Role/",
    pwb => "Pod/Weaver/PluginBundle/",
    pwp => "Pod/Weaver/Plugin/",
+   pwr => "Pod/Weaver/Role/",
    pws => "Pod/Weaver/Section/",
  }
 
